@@ -112,99 +112,6 @@ misc_message_box (const gchar *title,
 }
 
 
-/******************************************************************************
-*                                                                             *
-* ja:低レベル関数群                                                           *
-*                                                                             *
-******************************************************************************/
-/*  ja:スクロールバーを設定する
-       scroll,スクロールウイジット
-         func,シグナル関数
-    func_data,データ
-          min,最小値
-          max,最大値
-         page,ページ
-          pos,位置                                                          */
-void
-misc_set_scroll_bar (GtkWidget     *scroll,
-                     GtkSignalFunc  func,
-                     gpointer       func_data,
-                     const gint     min,
-                     const gint     max,
-                     const gint     page,
-                     const gint     pos)
-{
-  GtkAdjustment *adjust;
-
-  adjust = GTK_ADJUSTMENT (gtk_adjustment_new (pos, min, max, 1, page, page));
-  gtk_range_set_adjustment (GTK_RANGE (scroll), adjust);
-  if (func)
-    g_signal_connect (G_OBJECT (adjust), "value-changed", func, func_data);
-}
-
-
-/*  ja:Windowの内容をスクロールする
-    widget,ウイジット
-        dx,X軸方向の移動
-        dy,Y軸方向の移動
-         x,スクロールする範囲の右上X座標
-         y,スクロールする範囲の右上Y座標
-     width,スクロールする範囲の幅
-    height,スクロールする範囲の高さ                                         */
-void
-misc_scroll_window (GtkWidget  *widget,
-                    const gint  dx,
-                    const gint  dy,
-                    const gint  x,
-                    const gint  y,
-                    const gint  width,
-                    const gint  height)
-{
-  GdkGC *gc;
-  GdkRectangle rc;
-
-  if (ABS (dx) > width || ABS (dy) > height)
-    {
-      rc.x = x;
-      rc.y = y;
-      rc.width = width;
-      rc.height = height;
-      gtk_widget_draw (widget, &rc);
-    }
-  else if (dx != 0 || dy != 0)
-    {
-      gc = gdk_gc_new (widget->window);
-      gdk_gc_set_exposures (gc, TRUE);
-      gdk_window_copy_area (widget->window,
-                            gc,
-                            dx > 0 ? x + dx : x,
-                            dy > 0 ? y + dy : y,
-                            widget->window,
-                            dx > 0 ? x : x - dx,
-                            dy > 0 ? y : y - dy,
-                            width - ABS (dx),
-                            height - ABS (dy));
-      gdk_gc_destroy (gc);
-      if (dx != 0)
-        {
-          rc.x = dx > 0 ? x : x + width + dx;
-          rc.y = y;
-          rc.width = ABS (dx);
-          rc.height = height;
-          gtk_widget_draw (widget, &rc);
-        }
-      if (dy != 0)
-        {
-          rc.x = x;
-          rc.y = dy > 0 ? y : y + height + dy;
-          rc.width = width;
-          rc.height = ABS (dy);
-          gtk_widget_draw (widget, &rc);
-        }
-    }
-}
-
-
 /******************************************************************************
 *                                                                             *
 * ja:メニュー/ツールバー関数群                                                *
@@ -306,12 +213,15 @@ GtkWidget *
 misc_create_toolbar (MiscCreateToolbarEntry *entries)
 {
   gint i;
+  GtkTooltips *tooltips;
   GtkWidget *toolbar;
 
   toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
                                                 GTK_ORIENTATION_HORIZONTAL);
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
+  gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar), TRUE);
+  tooltips = gtk_tooltips_new ();
   for (i = 0; entries[i].path; i++)
     {
       if (entries[i].name)
@@ -325,6 +235,8 @@ misc_create_toolbar (MiscCreateToolbarEntry *entries)
           if (entries[i].func)
             g_signal_connect (G_OBJECT (entries[i].tool_item), "clicked",
                         G_CALLBACK (entries[i].func), entries[i].user_data);
+          gtk_tool_item_set_tooltip (entries[i].tool_item, tooltips,
+                                    _(entries[i].name), _(entries[i].name));
         }
       else
         {
@@ -353,6 +265,99 @@ misc_find_toolbar (MiscCreateToolbarEntry *entries,
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ja:低レベル関数群                                                           *
+*                                                                             *
+******************************************************************************/
+/*  ja:スクロールバーを設定する
+       scroll,スクロールウイジット
+         func,シグナル関数
+    func_data,データ
+          min,最小値
+          max,最大値
+         page,ページ
+          pos,位置                                                          */
+void
+misc_set_scroll_bar (GtkWidget     *scroll,
+                     GtkSignalFunc  func,
+                     gpointer       func_data,
+                     const gint     min,
+                     const gint     max,
+                     const gint     page,
+                     const gint     pos)
+{
+  GtkAdjustment *adjust;
+
+  adjust = GTK_ADJUSTMENT (gtk_adjustment_new (pos, min, max, 1, page, page));
+  gtk_range_set_adjustment (GTK_RANGE (scroll), adjust);
+  if (func)
+    g_signal_connect (G_OBJECT (adjust), "value-changed", func, func_data);
+}
+
+
+/*  ja:Windowの内容をスクロールする
+    widget,ウイジット
+        dx,X軸方向の移動
+        dy,Y軸方向の移動
+         x,スクロールする範囲の右上X座標
+         y,スクロールする範囲の右上Y座標
+     width,スクロールする範囲の幅
+    height,スクロールする範囲の高さ                                         */
+void
+misc_scroll_window (GtkWidget  *widget,
+                    const gint  dx,
+                    const gint  dy,
+                    const gint  x,
+                    const gint  y,
+                    const gint  width,
+                    const gint  height)
+{
+  GdkGC *gc;
+  GdkRectangle rc;
+
+  if (ABS (dx) > width || ABS (dy) > height)
+    {
+      rc.x = x;
+      rc.y = y;
+      rc.width = width;
+      rc.height = height;
+      gtk_widget_draw (widget, &rc);
+    }
+  else if (dx != 0 || dy != 0)
+    {
+      gc = gdk_gc_new (widget->window);
+      gdk_gc_set_exposures (gc, TRUE);
+      gdk_window_copy_area (widget->window,
+                            gc,
+                            dx > 0 ? x + dx : x,
+                            dy > 0 ? y + dy : y,
+                            widget->window,
+                            dx > 0 ? x : x - dx,
+                            dy > 0 ? y : y - dy,
+                            width - ABS (dx),
+                            height - ABS (dy));
+      gdk_gc_destroy (gc);
+      if (dx != 0)
+        {
+          rc.x = dx > 0 ? x : x + width + dx;
+          rc.y = y;
+          rc.width = ABS (dx);
+          rc.height = height;
+          gtk_widget_draw (widget, &rc);
+        }
+      if (dy != 0)
+        {
+          rc.x = x;
+          rc.y = dy > 0 ? y : y + height + dy;
+          rc.width = width;
+          rc.height = ABS (dy);
+          gtk_widget_draw (widget, &rc);
+        }
+    }
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:数値文字列関数群                                                         *
@@ -655,7 +660,7 @@ misc_str_to_float (gint        *value,
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
-misc_str_from_array (const gpointer *array,
+misc_str_from_array (gconstpointer  *array,
                      const gsize     size,
                      const gint      bits,
                      const gint      radix,
