@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -202,4 +202,4 @@ charset_block (const gchar *text);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __CHARSET_H__ */
