@@ -21,6 +21,7 @@
 #include "edit.h"
 #include "file.h"
 #include "find.h"
+#include "ftype.h"
 #include "general.h"
 #include "jump.h"
 #include "print.h"
@@ -30,11 +31,12 @@
 #include "repinfo.h"
 #include "sigfile.h"
 #include "valchr.h"
+#include "version.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_conf.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzconf.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
 # include <tchar.h>
@@ -48,9 +50,8 @@
 *                                                                             *
 ******************************************************************************/
 void
-command_new (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_new (GtkWidget *widget,
+             gpointer   user_data)
 {
   file_open_edit (NULL);
 }
@@ -72,9 +73,8 @@ command_open_ok (GtkWidget *widget,
 
 
 void
-command_open (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_open (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *file = NULL, *path;
 #if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
@@ -220,25 +220,24 @@ command_open (gpointer   callback_data,
 
 
 void
-command_save (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_save (GtkWidget *widget,
+              gpointer   user_data)
 {
   gint page_num;
   TmaidWindow *tmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
-  if (misc_mdi_get_created (MISC_MDI (mdi), page_num))
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+  if (orz_mdi_get_created (ORZ_MDI (mdi), page_num))
     {
-      command_saveas (callback_data, callback_action, widget);
+      command_saveas (widget, user_data);
     }
   else
     {
       gchar *text, *utf8str;
       const gchar *file;
 
-      file = misc_mdi_get_file (MISC_MDI (mdi), page_num);
+      file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
       utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
       text = g_strdup_printf (_("%s\nThis file is existed.\n\nOver write?"),
                                                                     utf8str);
@@ -248,7 +247,7 @@ command_save (gpointer   callback_data,
                                             _("_Yes"), _("_No"), NULL) == 0)
                                             && file_save_text (file, tmaid))
         {
-          misc_mdi_set_edited (MISC_MDI (mdi), page_num, FALSE);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
           if (delete_list (&tmaid->undo) + delete_list (&tmaid->redo) > 0)
             set_menu_bar (tmaid);
         }
@@ -257,9 +256,8 @@ command_save (gpointer   callback_data,
 
 
 void
-command_saveas (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_saveas (GtkWidget *widget,
+                gpointer   user_data)
 {
   gchar *file = NULL, *path;
 #if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
@@ -400,7 +398,7 @@ command_saveas (gpointer   callback_data,
       TmaidWindow *tmaid;
 
       page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-      tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
       utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
       text = g_strdup_printf (_("%s\nThis file is existed.\n\nOver write?"),
                                                                     utf8str);
@@ -415,13 +413,13 @@ command_saveas (gpointer   callback_data,
           save_path = g_path_get_dirname (path);
           g_free (path);
           /* ja:諸設定 */
-          misc_mdi_set_created (MISC_MDI (mdi), page_num, FALSE);
-          misc_mdi_set_edited (MISC_MDI (mdi), page_num, FALSE);
-          misc_mdi_set_file (MISC_MDI (mdi), page_num, file);
+          orz_mdi_set_created (ORZ_MDI (mdi), page_num, FALSE);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
+          orz_mdi_set_file (ORZ_MDI (mdi), page_num, file);
           delete_list (&tmaid->undo);
           delete_list (&tmaid->redo);
           set_menu_bar (tmaid);
-          misc_history_add_file (MISC_HISTORY (history), file);
+          orz_history_add_file (ORZ_HISTORY (history), file);
         }
       g_free (text);
       g_free (file);
@@ -430,9 +428,8 @@ command_saveas (gpointer   callback_data,
 
 
 void
-command_reload (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_reload (GtkWidget *widget,
+                gpointer   user_data)
 {
   gchar *text;
   const gchar *file;
@@ -441,9 +438,9 @@ command_reload (gpointer   callback_data,
   TmaidWindow *tmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
-  file = misc_mdi_get_file (MISC_MDI (mdi), page_num);
-  text = misc_mdi_get_edited (MISC_MDI (mdi), page_num) ? g_strdup_printf
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+  file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
+  text = orz_mdi_get_edited (ORZ_MDI (mdi), page_num) ? g_strdup_printf
             (_("File %s was edited.\nRestore to existed file?"), file) : NULL;
   if (reload_dialog (&tmaid->ft, text))
     {
@@ -467,7 +464,7 @@ command_reload (gpointer   callback_data,
       /* ja:右マージン */
       if (tmaid->ft.limit)
         modify_margin (tmaid);
-      misc_mdi_set_edited (MISC_MDI (mdi), page_num, FALSE);
+      orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
       misc_set_scroll_bar (tmaid->hscroll,
                 G_CALLBACK (signal_value_changed_hscroll), tmaid,
                 0, edit_get_width_max (tmaid) + 1,
@@ -488,13 +485,12 @@ command_reload (gpointer   callback_data,
 
 
 void
-command_print (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_print (GtkWidget *widget,
+               gpointer   user_data)
 {
   TmaidWindow *tmaid;
 
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   printer.select = tmaid->select.x >= 0;
   printer.column = tmaid->ft.margin;
   printer.font_width = tmaid->font_width;
@@ -505,14 +501,13 @@ command_print (gpointer   callback_data,
 
 
 void
-command_property (gpointer   callback_data,
-                  guint      callback_action,
-                  GtkWidget *widget)
+command_property (GtkWidget *widget,
+                  gpointer   user_data)
 {
   FileType ft;
   TmaidWindow *tmaid;
 
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   g_memset (&ft, 0, sizeof (FileType));
   property_copy (&ft, &tmaid->ft);
   ft.charset = g_strdup (tmaid->ft.charset);
@@ -537,9 +532,9 @@ command_property (gpointer   callback_data,
                 property_copy (ftype + i, &ft);
                 break;
               }
-          for (i = misc_mdi_get_n_pages (MISC_MDI (mdi)) - 1; i >= 0; i--)
+          for (i = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; i >= 0; i--)
             {
-              tmaid = misc_mdi_get_data (MISC_MDI (mdi), i);
+              tmaid = orz_mdi_get_data (ORZ_MDI (mdi), i);
               if (tmaid->ft.ft_id == ft.ft_id)
                 {
                   g_free (tmaid->ft.charset);
@@ -556,22 +551,20 @@ command_property (gpointer   callback_data,
 
 
 void
-command_close (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_close (GtkWidget *widget,
+               gpointer   user_data)
 {
   gint page;
 
   if ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0
-    && prompt_close ((TmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), page)))
+    && prompt_close ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), page)))
     gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
 }
 
 
 void
-command_exit (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_exit (GtkWidget *widget,
+              gpointer   user_data)
 {
   GdkEvent event;
 
@@ -583,39 +576,35 @@ command_exit (gpointer   callback_data,
 
 
 void
-command_undo (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_undo (GtkWidget *widget,
+              gpointer   user_data)
 {
-  history_operation ((TmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1),
+  history_operation ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1),
                                                                         FALSE);
 }
 
 
 void
-command_redo (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_redo (GtkWidget *widget,
+              gpointer   user_data)
 {
-  history_operation ((TmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1),
+  history_operation ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1),
                                                                         TRUE);
 }
 
 
 void
-command_cut (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_cut (GtkWidget *widget,
+             gpointer   user_data)
 {
-  command_copy (callback_data, callback_action, widget);
-  command_delete (callback_data, callback_action, widget);
+  command_copy (widget, user_data);
+  command_delete (widget, user_data);
 }
 
 
 void
-command_copy (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_copy (GtkWidget *widget,
+              gpointer   user_data)
 {
 
   if (gtk_selection_owner_set (window, GDK_SELECTION_CLIPBOARD,
@@ -624,7 +613,7 @@ command_copy (gpointer   callback_data,
       gint length;
       TmaidWindow *tmaid;
 
-      tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
       g_free (clipboard_text);
       length = edit_get_sel_bytes (tmaid, &tmaid->select, &tmaid->cursor);
       clipboard_text = g_malloc ((length + 1) * sizeof (gchar));
@@ -635,9 +624,8 @@ command_copy (gpointer   callback_data,
 
 
 void
-command_paste (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_paste (GtkWidget *widget,
+               gpointer   user_data)
 {
   /* ja:Windowsのセレクションの実装があやしいので暫定的処理 */
 #ifdef G_OS_WIN32
@@ -671,7 +659,7 @@ command_paste (gpointer   callback_data,
           TmaidWindow *tmaid;
 
           page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-          tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
           select = tmaid->select;
           d = edit_operation (tmaid, text, g_strlen (text), TRUE, FALSE);
           g_free (text);
@@ -679,7 +667,7 @@ command_paste (gpointer   callback_data,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
         }
     }
 #else /* not G_OS_WIN32 */
@@ -690,50 +678,46 @@ command_paste (gpointer   callback_data,
 
 
 void
-command_delete (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_delete (GtkWidget *widget,
+                gpointer   user_data)
 {
   gint page_num;
   TmaidHistory *d;
   TmaidWindow *tmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   d = edit_operation (tmaid, NULL, 0, TRUE, FALSE);
   d->next = tmaid->undo;
   tmaid->undo = d;
   set_menu_bar (tmaid);
-  misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
 }
 
 
 void
-command_margin (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_margin (GtkWidget *widget,
+                gpointer   user_data)
 {
   if (misc_message_box ("Text maid", _("Return at Right Margin?"), 1,
                                             _("_Yes"), _("_No"), NULL) == 0)
-    margin_operation ((TmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1));
+    margin_operation ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
 
 void
-command_tab (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_tab (GtkWidget *widget,
+             gpointer   user_data)
 {
   if (misc_message_box ("Text maid", _("Convert Tab to Space?"), 1,
                                             _("_Yes"), _("_No"), NULL) == 0)
-    tab_operation ((TmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1));
+    tab_operation ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
 
 void
-command_valchr (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_valchr (GtkWidget *widget,
+                gpointer   user_data)
 {
   gchar valchr;
 
@@ -745,27 +729,26 @@ command_valchr (gpointer   callback_data,
       TmaidWindow *tmaid;
 
       page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-      tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
       select = tmaid->select;
       d = edit_operation (tmaid, &valchr, 1, TRUE, FALSE);
       d->next = tmaid->undo;
       tmaid->undo = d;
       if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
         set_menu_bar (tmaid);
-      misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+      orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
     }
 }
 
 
 void
-command_jump (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_jump (GtkWidget *widget,
+              gpointer   user_data)
 {
   JumpDialog jmp;
   TmaidWindow *tmaid;
 
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   jmp.max = tmaid->max;
   jmp.cursor = tmaid->cursor.y + 1;
   if (jump_dialog (&jmp) && tmaid->cursor.y != jmp.cursor - 1)
@@ -774,15 +757,14 @@ command_jump (gpointer   callback_data,
 
 
 void
-command_all (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_all (GtkWidget *widget,
+             gpointer   user_data)
 {
   gint sx, sy;
   GdkPoint top;
   TmaidWindow *tmaid;
 
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   if (tmaid->max <= 1 && tmaid->start->length <= 0)
     return;
   top = tmaid->top;
@@ -814,14 +796,13 @@ command_all (gpointer   callback_data,
 
 
 void
-command_find (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_find (GtkWidget *widget,
+              gpointer   user_data)
 {
   FindString fd;
   TmaidWindow *tmaid;
 
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   fd.text = NULL;
   fd.arrow = find_arrow;
   fd.ignorecase = find_ignorecase;
@@ -861,27 +842,26 @@ command_find (gpointer   callback_data,
               find_text[0] = text;
             }
         }
-      command_next (callback_data, callback_action, widget);
+      command_next (widget, (gpointer)TRUE);
     }
 }
 
 
 void
-command_next (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_next (GtkWidget *widget,
+              gpointer   user_data)
 {
   GtkWidget *dialog;
   TmaidWindow *tmaid;
 
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   /* en:Dialog Box */
   /* ja:ダイアログボックス */
   userbreak = TRUE;
   dialog = abort_dialog (_("Finding"));
   gtk_grab_add (dialog);
   find_operation (tmaid, &tmaid->cursor, &tmaid->select, find_text[0],
-                callback_action ? !find_arrow : find_arrow, find_ignorecase);
+            (gboolean)user_data ? find_arrow : !find_arrow, find_ignorecase);
   gtk_grab_remove (dialog);
   gtk_widget_destroy (dialog);
   if (userbreak && tmaid->select.x < 0)
@@ -897,9 +877,8 @@ command_next (gpointer   callback_data,
 
 
 void
-command_replace (gpointer   callback_data,
-                 guint      callback_action,
-                 GtkWidget *widget)
+command_replace (GtkWidget *widget,
+                 gpointer   user_data)
 {
   gboolean replace = FALSE;
   gint page_num, result;
@@ -907,7 +886,7 @@ command_replace (gpointer   callback_data,
   ReplaceString rp;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   rp.src = rp.dst = NULL;
   rp.arrow = replace_arrow;
   rp.ignorecase = replace_ignorecase;
@@ -1033,7 +1012,7 @@ command_replace (gpointer   callback_data,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next)
             set_menu_bar (tmaid);
-          misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
         }
       while (result != REPLACE_CANCEL);
       /* en:Dialog Box */
@@ -1064,12 +1043,12 @@ static void
 command_conf_ok (GtkWidget *widget,
                  GtkWidget *dialog)
 {
-  misc_history_set_num (MISC_HISTORY (history),
-                                misc_conf_get_history (MISC_CONF (dialog)));
-  newfile = misc_conf_get_newfile (MISC_CONF (dialog));
-  second = misc_conf_get_second (MISC_CONF (dialog));
-  misc_conf_get_size (MISC_CONF (dialog), &def_width, &def_height);
-  n_pos = misc_conf_get_tab (MISC_CONF (dialog));
+  orz_history_set_num (ORZ_HISTORY (history),
+                                    orz_conf_get_history (ORZ_CONF (dialog)));
+  newfile = orz_conf_get_newfile (ORZ_CONF (dialog));
+  second = orz_conf_get_second (ORZ_CONF (dialog));
+  orz_conf_get_size (ORZ_CONF (dialog), &def_width, &def_height);
+  n_pos = orz_conf_get_tab (ORZ_CONF (dialog));
   gtk_widget_destroy (dialog);
   /* ja:ノートの位置 */
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
@@ -1077,26 +1056,41 @@ command_conf_ok (GtkWidget *widget,
 
 
 void
-command_conf (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_conf (GtkWidget *widget,
+              gpointer   user_data)
 {
   GtkWidget *dialog;
 
-  dialog = misc_conf_new ();
+  dialog = orz_conf_new ();
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (MISC_CONF (dialog)->ok_button),
+  g_signal_connect (G_OBJECT (ORZ_CONF (dialog)->ok_button),
                             "clicked", G_CALLBACK (command_conf_ok), dialog);
-  g_signal_connect_swapped (G_OBJECT (MISC_CONF (dialog)->cancel_button),
+  g_signal_connect_swapped (G_OBJECT (ORZ_CONF (dialog)->cancel_button),
             "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  misc_conf_set_history (MISC_CONF(dialog),
-                                misc_history_get_num (MISC_HISTORY (history)));
-  misc_conf_set_newfile (MISC_CONF(dialog), newfile);
-  misc_conf_set_second (MISC_CONF(dialog), second);
-  misc_conf_set_size (MISC_CONF(dialog), def_width, def_height);
-  misc_conf_set_tab (MISC_CONF(dialog), n_pos);
+  orz_conf_set_history (ORZ_CONF(dialog),
+                                orz_history_get_num (ORZ_HISTORY (history)));
+  orz_conf_set_newfile (ORZ_CONF (dialog), newfile);
+  orz_conf_set_second (ORZ_CONF (dialog), second);
+  orz_conf_set_size (ORZ_CONF (dialog), def_width, def_height);
+  orz_conf_set_tab (ORZ_CONF (dialog), n_pos);
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
 }
+
+
+void
+command_format (GtkWidget *widget,
+                gpointer   user_data)
+{
+  ftype_dialog (FALSE);
+}
+
+
+void
+command_version (GtkWidget *widget,
+                 gpointer   user_data)
+{
+  version_dialog ();
+}
