@@ -27,8 +27,8 @@
 #include "misc/charuty.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -481,7 +481,7 @@ file_open_edit (const gchar *file)
                             GTK_FILL,GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
   g_object_set_data (G_OBJECT(table), "user_data", tmaid);
   /* ja:表示 */
-  page_num = misc_mdi_append_page (MISC_MDI (mdi),
+  page_num = orz_mdi_append_page (ORZ_MDI (mdi),
                                                 table, filename, !file, tmaid);
   gtk_widget_show_all (table);
   gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
@@ -499,7 +499,7 @@ file_open_edit (const gchar *file)
   gtk_im_context_set_cursor_location (tmaid->im_context, &rc);
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
   if (file && fileio_isfile (file))
-    misc_history_add_file (MISC_HISTORY (history), file);
+    orz_history_add_file (ORZ_HISTORY (history), file);
   g_free (filename);
   /* ja:右マージン */
   if (tmaid->ft.limit)
