@@ -62,4 +62,4 @@ file_save_text (const gchar *file,
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __FILE_H__ */
