@@ -25,7 +25,7 @@
 #include "toolbar.h"
 #include "misc/charuty.h"
 #include "misc/misc.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -136,83 +136,101 @@ set_menu_bar (TmaidWindow *tmaid)
     {
       gboolean created;
 
-      created = misc_mdi_get_created (MISC_MDI (mdi),
-                        misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid));
-      gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-            (gtk_item_factory_get_widget (ifactory_menu, "<main>/Edit"))),
-                                                                        TRUE);
-      gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-            (gtk_item_factory_get_widget (ifactory_menu, "<main>/Search"))),
-                                                                        TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Close"), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save"), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save As..."), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload..."), !created);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Print..."), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Properties..."), TRUE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Edit/Undo"), tmaid->undo != NULL);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Edit/Redo"), tmaid->redo != NULL);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Edit/Cut"), tmaid->select.x >= 0);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Edit/Copy"), tmaid->select.x >= 0);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Edit/Delete"), tmaid->select.x >= 0);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Search/Next"), find_num > 0);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/Search/Previous"), find_num > 0);
-      gtk_widget_set_sensitive (toolbar_items[ 2].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[ 4].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[ 6].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[ 8].item, tmaid->select.x >= 0);
-      gtk_widget_set_sensitive (toolbar_items[ 9].item, tmaid->select.x >= 0);
-      gtk_widget_set_sensitive (toolbar_items[10].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[11].item, tmaid->select.x >= 0);
-      gtk_widget_set_sensitive (toolbar_items[13].item, tmaid->undo != NULL);
-      gtk_widget_set_sensitive (toolbar_items[14].item, tmaid->redo != NULL);
-      gtk_widget_set_sensitive (toolbar_items[16].item, TRUE);
-      gtk_widget_set_sensitive (toolbar_items[17].item, TRUE);
+      created = orz_mdi_get_created (ORZ_MDI (mdi),
+                            orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid));
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/file/close"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/file/save"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/file/saveas"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/file/reload"), !created);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/file/print"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/file/properties"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/edit"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/edit/undo"), tmaid->undo != NULL);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/edit/redo"), tmaid->redo != NULL);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/edit/cut"), tmaid->select.x >= 0);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/edit/copy"), tmaid->select.x >= 0);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/edit/delete"), tmaid->select.x >= 0);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/search"), TRUE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/search/next"), find_num > 0);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                        "/search/previous"), find_num > 0);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "save")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "properties")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "print")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "cut")), tmaid->select.x >= 0);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "copy")), tmaid->select.x >= 0);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "paste")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "delete")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "undo")), tmaid->undo != NULL);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "redo")), tmaid->redo != NULL);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "find")), TRUE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                            "replace")), TRUE);
     }
   else
     {
-      gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-            (gtk_item_factory_get_widget (ifactory_menu, "<main>/Edit"))),
-                                                                        FALSE);
-      gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-            (gtk_item_factory_get_widget (ifactory_menu, "<main>/Search"))),
-                                                                        FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Close"), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save"), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Save As..."), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload..."), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Print..."), FALSE);
-      gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Properties..."), FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 2].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 4].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 6].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 8].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[ 9].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[10].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[11].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[13].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[14].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[16].item, FALSE);
-      gtk_widget_set_sensitive (toolbar_items[17].item, FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/file/close"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/file/save"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/file/saveas"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/file/reload"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/file/print"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/file/properties"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/edit"), FALSE);
+      gtk_widget_set_sensitive (misc_find_menu (menu_entries,
+                                                "/search"), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "save")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "properties")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "print")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "cut")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "copy")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "paste")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "delete")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "undo")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "redo")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "find")), FALSE);
+      gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
+                                                        "replace")), FALSE);
     }
 }
 
@@ -577,13 +595,13 @@ prompt_close (TmaidWindow *tmaid)
 {
   gint page;
 
-  page = misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid);
-  if (misc_mdi_get_edited (MISC_MDI (mdi), page))
+  page = orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid);
+  if (orz_mdi_get_edited (ORZ_MDI (mdi), page))
     {
       gchar *text, *utf8str;
 
       utf8str = g_filename_to_utf8
-            (misc_mdi_get_file (MISC_MDI (mdi), page), -1, NULL, NULL, NULL);
+            (orz_mdi_get_file (ORZ_MDI (mdi), page), -1, NULL, NULL, NULL);
       text = g_strdup_printf (_("File %s was edited.\nSave?"), utf8str);
       g_free (utf8str);
       switch (misc_message_box ("Text maid", text, 0,
@@ -598,10 +616,10 @@ prompt_close (TmaidWindow *tmaid)
                 gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page);
               else
                 page_num = -1;
-              command_save (NULL, 0, NULL);
+              command_save (NULL, NULL);
               if (page_num >= 0)
                 gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page_num);
-              if (!misc_mdi_get_edited (MISC_MDI (mdi), page))
+              if (!orz_mdi_get_edited (ORZ_MDI (mdi), page))
                 break;
             }
           case 2:
@@ -633,11 +651,11 @@ charlist_renewal_all (const gchar *charlist,
       g_free (ftype[i].charset);
       ftype[i].charset = charset;
     }
-  for (i = misc_mdi_get_n_pages (MISC_MDI (mdi)) - 1; i >= 0; i--)
+  for (i = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; i >= 0; i--)
     {
       TmaidWindow *tmaid;
 
-      tmaid = misc_mdi_get_data (MISC_MDI (mdi), i);
+      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), i);
       charset = charuty_rename (tmaid->ft.charset, charlist);
       g_free (tmaid->ft.charset);
       tmaid->ft.charset = charset;
@@ -713,8 +731,8 @@ margin_operation (TmaidWindow *tmaid)
       p = p->next;
     }
   tmaid->ft.limit = limit;
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
   tmaid->cursor.x = tmaid->cursor.y = tmaid->top.x = tmaid->top.y = 0;
   tmaid->select.x = -1;
   misc_set_scroll_bar (tmaid->hscroll,
@@ -779,8 +797,8 @@ tab_operation (TmaidWindow *tmaid)
           }
       p = p->next;
     }
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
   tmaid->select.x = -1;
   set_menu_bar (tmaid);
   gtk_widget_draw (tmaid->drawing, NULL);
