@@ -138,4 +138,4 @@ tab_operation (TmaidWindow *tmaid);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __GENERAL_H__ */
