@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,8 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-typedef struct PrintConfig_Tag {
+typedef struct _PrintConfig
+{
     gboolean select;
     gint column, font_width, font_height;
     gint width, height;
@@ -85,4 +86,4 @@ print_dialog (PrintConfig *prncfg);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __PRINT_H__ */
