@@ -17,8 +17,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
-#include "misc/misc_charset.h"
 #include "reload.h"
+#include "orz/orzcharset.h"
 
 
 /******************************************************************************
@@ -36,7 +36,7 @@ reload_dialog_ok_sensitive (GtkWidget *widget,
                             gpointer   user_data)
 {
   gtk_widget_set_sensitive (button0,
-                            misc_charset_is_valid (MISC_CHARSET (charset)));
+                            orz_charset_is_valid (ORZ_CHARSET (charset)));
 }
 
 
@@ -66,7 +66,7 @@ reload_dialog_clicked (GtkWidget *widget,
   if (ft->crlf < 0)
     ft->crlf = 0;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  ft->charset = misc_charset_get_charset (MISC_CHARSET (charset));
+  ft->charset = orz_charset_get_charset (ORZ_CHARSET (charset));
   gtk_widget_destroy (dialog);
   reload_clicked_ok = TRUE;
 }
@@ -166,10 +166,10 @@ reload_dialog (FileType    *ft,
                                 G_CALLBACK (reload_dialog_ok_sensitive), NULL);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:文字符号化方式 */
-  charset = misc_charset_new ();
+  charset = orz_charset_new ();
   for (i = 0; i < ftnum; i++)
-    misc_charset_add_candidate (MISC_CHARSET (charset), ftype[i].charset);
-  misc_charset_set_charset (MISC_CHARSET (charset), ft->charset);
+    orz_charset_add_candidate (ORZ_CHARSET (charset), ftype[i].charset);
+  orz_charset_set_charset (ORZ_CHARSET (charset), ft->charset);
   g_signal_connect (G_OBJECT (charset), "activate",
                                     G_CALLBACK (reload_dialog_activate), ft);
   g_signal_connect (G_OBJECT (charset), "edited",
