@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,12 +28,12 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-typedef struct ReplaceInfo_Tag
+typedef struct _ReplaceInfo
 {
   gboolean arrow;
   gboolean ignorecase;
-  gchar *src,*dst;
-  GdkPoint start,end;
+  gchar *src, *dst;
+  GdkPoint start, end;
 } ReplaceInfo;
 
 
@@ -54,4 +54,4 @@ repinfo_dialog (ReplaceInfo *ri);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __REPINFO_H__ */
