@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ extern "C" {
 #define REPLACE_NEXT 0
 
 
-typedef struct ReplaceString_Tag
+typedef struct _ReplaceString
 {
   gboolean arrow;
   gboolean ignorecase;
@@ -65,4 +65,4 @@ replace_dialog (ReplaceString *rp);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __REPLACE_H__ */
