@@ -23,7 +23,7 @@
 #include "sigfile.h"
 #include "sigkey.h"
 #include "misc/misc.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -330,8 +330,8 @@ signal_key_press (GtkWidget   *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
         }
         result=TRUE;
         break;
@@ -370,8 +370,8 @@ signal_key_press (GtkWidget   *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
@@ -404,15 +404,15 @@ signal_key_press (GtkWidget   *widget,
               tmaid->undo = d;
               if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
                 set_menu_bar (tmaid);
-              misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+              orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
             }
           else
             {
               gint page;
               guint length;
 
-              length = misc_mdi_get_n_pages (MISC_MDI (mdi));
+              length = orz_mdi_get_n_pages (ORZ_MDI (mdi));
               page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
               if (event->state & GDK_SHIFT_MASK)
                 {
@@ -426,7 +426,7 @@ signal_key_press (GtkWidget   *widget,
                 }
               gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page);
               gtk_widget_grab_focus (((TmaidWindow *)
-                        misc_mdi_get_data (MISC_MDI (mdi), page))->drawing);
+                            orz_mdi_get_data (ORZ_MDI (mdi), page))->drawing);
             }
         }
         result=TRUE;
@@ -506,8 +506,8 @@ signal_key_press (GtkWidget   *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
@@ -557,8 +557,8 @@ signal_key_press (GtkWidget   *widget,
             tmaid->undo = d;
             if (delete_list(&tmaid->redo) > 0 || !d->next || select.x >= 0)
               set_menu_bar (tmaid);
-              misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+              orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
@@ -566,6 +566,7 @@ signal_key_press (GtkWidget   *widget,
         {
           gint sx, sy;
           GdkPoint top;
+          GtkWidget *menu_shell, *menu_item;
 
           if (!(event->state & GDK_SHIFT_MASK))
             break;
@@ -589,16 +590,22 @@ signal_key_press (GtkWidget   *widget,
             misc_set_scroll_bar (tmaid->vscroll,
                         G_CALLBACK (signal_value_changed_vscroll), tmaid,
                         0, tmaid->max, sy, tmaid->top.y);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Undo"), tmaid->undo != NULL);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Cut"), tmaid->select.x >= 0);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Copy"), tmaid->select.x >= 0);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Delete"), tmaid->select.x >= 0);
-          gtk_menu_popup (GTK_MENU
-                    (gtk_item_factory_get_widget (ifactory_popup,"<main>")),
+
+          menu_item = misc_find_menu (popup_entries, "/input");
+          gtk_menu_item_remove_submenu (GTK_MENU_ITEM (menu_item));
+          menu_shell = gtk_menu_new ();
+          gtk_im_multicontext_append_menuitems (GTK_IM_MULTICONTEXT
+                            (tmaid->im_context), GTK_MENU_SHELL (menu_shell));
+          gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu_shell);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/undo"), tmaid->undo != NULL);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/cut"), tmaid->select.x >= 0);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/copy"), tmaid->select.x >= 0);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/delete"), tmaid->select.x >= 0);
+          gtk_menu_popup (GTK_MENU (misc_find_menu (popup_entries, "/")),
                                     NULL, NULL, NULL, NULL, 3, event->time);
         }
         result = TRUE;
