@@ -128,4 +128,4 @@ signal_delete (GtkWidget *widget,
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __SIGMAIN_H__ */
