@@ -21,7 +21,6 @@
 #include "command.h"
 #include "file.h"
 #include "find.h"
-#include "format.h"
 #include "general.h"
 #include "jump.h"
 #include "print.h"
@@ -29,17 +28,16 @@
 #include "sigfile.h"
 #include "sigmain.h"
 #include "toolbar.h"
-#include "version.h"
 #include "misc/argument.h"
 #include "misc/charuty.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
-#include "misc/misc_accel.h"
-#include "misc/misc_comm.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
-#include "misc/misc_winmenu.h"
 #include "misc/profile.h"
+#include "orz/orzaccel.h"
+#include "orz/orzcomm.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
+#include "orz/orzwinmenu.h"
 
 
 gboolean caret = FALSE;             /* ja:キャレットの形 */
@@ -82,6 +80,68 @@ GtkTargetEntry targets[4] = {       /* ja:Text maidが提供可能なセレク
     {"TEXT",          0, TARGET_TEXT}, 
     {"COMPOUND_TEXT", 0, TARGET_COMPOUND_TEXT},
     {"UTF8_STRING",   0, TARGET_UTF8}};
+MiscCreateMenuEntry menu_entries[] = {
+{"/",                     NULL,                          NULL,         MISC_CREATE_MENU_BAR,       NULL,             NULL,            NULL},
+{"/file",                 N_("_File"),                   NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{"/file/",                NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/file/new",             N_("_New"),                    "<control>N", MISC_CREATE_MENU_ITEM,      command_new,      NULL,            NULL},
+{"/file/open",            N_("_Open..."),                "<control>O", MISC_CREATE_MENU_ITEM,      command_open,     NULL,            NULL},
+{"/file/close",           N_("_Close"),                  "<control>W", MISC_CREATE_MENU_ITEM,      command_close,    NULL,            NULL},
+{"/file/save",            N_("_Save"),                   "<control>S", MISC_CREATE_MENU_ITEM,      command_save,     NULL,            NULL},
+{"/file/saveas",          N_("Save _As..."),             NULL,         MISC_CREATE_MENU_ITEM,      command_saveas,   NULL,            NULL},
+{"/file/reload",          N_("_Reload..."),              "<control>R", MISC_CREATE_MENU_ITEM,      command_reload,   NULL,            NULL},
+{"/file/sep1",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/file/print",           N_("_Print..."),               "<control>P", MISC_CREATE_MENU_ITEM,      command_print,    NULL,            NULL},
+{"/file/sep2",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/file/properties",      N_("Propert_ies..."),          "<alt>Return",MISC_CREATE_MENU_ITEM,      command_property, NULL,            NULL},
+{"/file/sep3",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/file/exit",            N_("E_xit"),                   "<control>Q", MISC_CREATE_MENU_ITEM,      command_exit,     NULL,            NULL},
+{"/edit",                 N_("_Edit"),                   NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{"/edit/",                NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/edit/undo",            N_("_Undo"),                   "<control>Z", MISC_CREATE_MENU_ITEM,      command_undo,     NULL,            NULL},
+{"/edit/redo",            N_("_Redo"),                   "F4",         MISC_CREATE_MENU_ITEM,      command_redo,     NULL,            NULL},
+{"/edit/sep1",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/edit/cut",             N_("Cu_t"),                    "<control>X", MISC_CREATE_MENU_ITEM,      command_cut,      NULL,            NULL},
+{"/edit/copy",            N_("_Copy"),                   "<control>C", MISC_CREATE_MENU_ITEM,      command_copy,     NULL,            NULL},
+{"/edit/paste",           N_("_Paste"),                  "<control>V", MISC_CREATE_MENU_ITEM,      command_paste,    NULL,            NULL},
+{"/edit/delete",          N_("De_lete"),                 NULL,         MISC_CREATE_MENU_ITEM,      command_delete,   NULL,            NULL},
+{"/edit/sep2",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/edit/return",          N_("Return at Right _Margin"), NULL,         MISC_CREATE_MENU_ITEM,      command_margin,   NULL,            NULL},
+{"/edit/convert",         N_("Convert Ta_b to Space"),   NULL,         MISC_CREATE_MENU_ITEM,      command_tab,      NULL,            NULL},
+{"/edit/sep3",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/edit/character",       N_("_Character by _Value..."), NULL,         MISC_CREATE_MENU_ITEM,      command_valchr,   NULL,            NULL},
+{"/edit/jump",            N_("_Jump..."),                "<control>J", MISC_CREATE_MENU_ITEM,      command_jump,     NULL,            NULL},
+{"/edit/sep4",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/edit/all",             N_("_All"),                    "<control>A", MISC_CREATE_MENU_ITEM,      command_all,      NULL,            NULL},
+{"/search",               N_("_Search"),                 NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{"/search/",              NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/search/find",          N_("_Find..."),                "<control>F", MISC_CREATE_MENU_ITEM,      command_find,     NULL,            NULL},
+{"/search/next",          N_("_Next"),                   "F3",         MISC_CREATE_MENU_ITEM,      command_next,     (gpointer)TRUE,  NULL},
+{"/search/previous",      N_("_Previous"),               "<shift>F3",  MISC_CREATE_MENU_ITEM,      command_next,     (gpointer)FALSE, NULL},
+{"/search/next",          N_("_Replace..."),             "<control>H", MISC_CREATE_MENU_ITEM,      command_replace,  NULL,            NULL},
+{"/option",               N_("_Option"),                 NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{"/option/",              NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/option/configuration", N_("_Configuration..."),       NULL,         MISC_CREATE_MENU_ITEM,      command_conf,     NULL,            NULL},
+{"/option/file",          N_("File _Type..."),           NULL,         MISC_CREATE_MENU_ITEM,      command_format,   NULL,            NULL},
+{"/window",               N_("_Window"),                 NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{"/window/",              NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/help",                 N_("_Help"),                   NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{"/help/",                NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/help/about",           N_("_About..."),               NULL,         MISC_CREATE_MENU_ITEM,      command_version,  NULL,            NULL},
+{NULL,                    NULL,                          NULL,         MISC_CREATE_MENU_TERMINAL,  NULL,             NULL,            NULL}};
+MiscCreateMenuEntry popup_entries[] = {
+{"/",                     NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,            NULL},
+{"/undo",                 N_("_Undo"),                   "<control>Z", MISC_CREATE_MENU_ITEM,      command_undo,     NULL,            NULL},
+{"/sep1",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/cut",                  N_("Cu_t"),                    "<control>X", MISC_CREATE_MENU_ITEM,      command_cut,      NULL,            NULL},
+{"/copy",                 N_("_Copy"),                   "<control>C", MISC_CREATE_MENU_ITEM,      command_copy,     NULL,            NULL},
+{"/paste",                N_("_Paste"),                  "<control>V", MISC_CREATE_MENU_ITEM,      command_paste,    NULL,            NULL},
+{"/delete",               N_("De_lete"),                 NULL,         MISC_CREATE_MENU_ITEM,      command_delete,   NULL,            NULL},
+{"/sep2",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/all",                  N_("_All"),                    "<control>A", MISC_CREATE_MENU_ITEM,      command_all,      NULL,            NULL},
+{"/sep3",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,            NULL},
+{"/input",                N_("_Input Methods"),          NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,            NULL},
+{NULL,                    NULL,                          NULL,         MISC_CREATE_MENU_TERMINAL,  NULL,             NULL,            NULL}};
 
 
 /******************************************************************************
@@ -89,14 +149,6 @@ GtkTargetEntry targets[4] = {       /* ja:Text maidが提供可能なセレク
 * ja:メイン関数                                                               *
 *                                                                             *
 ******************************************************************************/
-static gchar *
-menu_translate (const gchar *path,
-                gpointer     func_data)
-{
- return (gchar *)_(path);
-}
-
-
 int
 main (int   argc,
       char *argv[])
@@ -110,59 +162,7 @@ main (int   argc,
   GObject *accel, *winmenu;
   GtkAccelGroup *accel_group;
   GtkStyle *style;
-  GtkWidget *menu_bar, *handle, *label, *table, *toolbar, *vbox, *frame;
-  GtkItemFactoryEntry menu_items[] = {
-{N_("/_File"),                       NULL,         NULL,            0,"<Branch>"},
-{N_("/File/_New"),                   "<control>N", command_new,     0,"<Item>"},
-{N_("/File/_Open..."),               "<control>O", command_open,    0,"<Item>"},
-{N_("/File/_Close"),                 "<control>W", command_close,   0,"<Item>"},
-{N_("/File/_Save"),                  "<control>S", command_save,    0,"<Item>"},
-{N_("/File/Save _As..."),            NULL,         command_saveas,  0,"<Item>"},
-{N_("/File/_Reload..."),             "<control>R", command_reload,  0,"<Item>"},
-{N_("/File/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/File/_Print..."),              "<control>P", command_print,   0,"<Item>"},
-{N_("/File/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/File/Propert_ies..."),         "<alt>Return",command_property,0,"<Item>"},
-{N_("/File/Sep3"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/File/E_xit"),                  "<control>Q", command_exit,    0,"<Item>"},
-{N_("/_Edit"),                       NULL,         NULL,            0,"<Branch>"},
-{N_("/Edit/_Undo"),                  "<control>Z", command_undo,    0,"<Item>"},
-{N_("/Edit/_Redo"),                  "F4",         command_redo,    0,"<Item>"},
-{N_("/Edit/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/Cu_t"),                   "<control>X", command_cut,     0,"<Item>"},
-{N_("/Edit/_Copy"),                  "<control>C", command_copy,    0,"<Item>"},
-{N_("/Edit/_Paste"),                 "<control>V", command_paste,   0,"<Item>"},
-{N_("/Edit/De_lete"),                NULL,         command_delete,  0,"<Item>"},
-{N_("/Edit/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/Return at Right _Margin"),NULL,         command_margin,  0,"<Item>"},
-{N_("/Edit/Convert Ta_b to Space"),  NULL,         command_tab,     0,"<Item>"},
-{N_("/Edit/Sep3"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/_Character by _Value..."),NULL,         command_valchr,  0,"<Item>"},
-{N_("/Edit/_Jump..."),               "<control>J", command_jump,    0,"<Item>"},
-{N_("/Edit/Sep4"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/_All"),                   "<control>A", command_all,     0,"<Item>"},
-{N_("/_Search"),                     NULL,         NULL,            0,"<Branch>"},
-{N_("/Search/_Find..."),             "<control>F", command_find,    0,"<Item>"},
-{N_("/Search/_Next"),                "F3",         command_next,    0,"<Item>"},
-{N_("/Search/_Previous"),            "<shift>F3",  command_next,    1,"<Item>"},
-{N_("/Search/_Replace..."),          "<control>H", command_replace, 0,"<Item>"},
-{N_("/_Option"),                     NULL,         NULL,            0,"<Branch>"},
-{N_("/Option/_Configuration..."),    NULL,         command_conf,    0,"<Item>"},
-{N_("/Option/File _Type..."),        NULL,         format_dialog,   0,"<Item>"},
-{N_("/_Window"),                     NULL,         NULL,            0,"<Branch>"},
-{N_("/_Help"),                       NULL,         NULL,            0,"<Branch>"},
-{N_("/Help/_About..."),              NULL,         version_dialog,  0,"<Item>"}};
-    GtkItemFactoryEntry popup_items[] = {
-{N_("/_Undo"),                       "<control>Z", command_undo,    0,"<Item>"},
-{"/Sep1",                            NULL,         NULL,            0,"<Separator>"},
-{N_("/Cu_t"),                        "<control>X", command_cut,     0,"<Item>"},
-{N_("/_Copy"),                       "<control>C", command_copy,    0,"<Item>"},
-{N_("/_Paste"),                      "<control>V", command_paste,   0,"<Item>"},
-{N_("/De_lete"),                     NULL,         command_delete,  0,"<Item>"},
-{"/Sep2",                            NULL,         NULL,            0,"<Separator>"},
-{N_("/_All"),                        "<control>A", command_all,     0,"<Item>"},
-{"/Sep3",                            NULL,         NULL,            0,"<Separator>"},
-{N_("/_Input Methods"),              NULL,         NULL,            0,"<Item>"}};
+  GtkWidget *handle, *label, *table, *vbox, *frame;
   /* en:Drag&Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
 
@@ -192,7 +192,7 @@ main (int   argc,
   def_height = gdk_screen_height () * 2 / 3;
 
   /* ja:ファイルの履歴 */
-  history = misc_history_new ();
+  history = orz_history_new ();
 
   /* ja:レジストリから読み出す */
   profile = profile_open (NULL);
@@ -213,7 +213,7 @@ main (int   argc,
 #endif /* GTK_CHECK_VERSION(2,4,0) or defined G_OS_WIN32 */
       if (profile_get_value (profile, "tmaid", "history",
             (gpointer)&num, sizeof (gint), PROFILE_VALUE_TYPE_INT))
-        misc_history_set_num (MISC_HISTORY (history), num);
+        orz_history_set_num (ORZ_HISTORY (history), num);
       if (!profile_get_value (profile, "tmaid", "newfile",
             (gpointer)&newfile, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL))
         newfile = FALSE;
@@ -238,7 +238,7 @@ main (int   argc,
                 ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
       g_free (utf8str);
       /* ja:ファイルの履歴 */
-      for (i = misc_history_get_num (MISC_HISTORY (history)) - 1; i >= 0; i--)
+      for (i = orz_history_get_num (ORZ_HISTORY (history)) - 1; i >= 0; i--)
         {
           key = g_strdup_printf ("history%d", i);
           utf8str = profile_get_string (profile, "tmaid", key);
@@ -249,7 +249,7 @@ main (int   argc,
 
               file = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
               g_free (utf8str);
-              misc_history_add_file (MISC_HISTORY (history), file);
+              orz_history_add_file (ORZ_HISTORY (history), file);
               g_free (file);
             }
         }
@@ -503,8 +503,8 @@ main (int   argc,
 {NULL,      '\0', NULL,           NULL,                 0,                   NULL}};
 
     /* ja:ファイルの履歴 */
-    arg_h.val = misc_history_get_num (MISC_HISTORY (history));
-    arg_h.def = MISC_HISTORY_NUM_DEF;
+    arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
+    arg_h.def = ORZ_HISTORY_NUM_DEF;
     /* ja:初期のキャレット位置 */
     arg_l.val = init_line;
     arg_l.def = 0;
@@ -531,7 +531,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
     /* ja:ヘルプ */
     arg_q.str = TMAID_COPYRIGHT_NOTICE"\n\n";
     arg_files = arg_analyse (argv, arg_opts);
-    misc_history_set_num (MISC_HISTORY (history), arg_h.val);
+    orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
     if (arg_l.val >= 0)
       init_line = arg_l.val;
     def_width = array[0];
@@ -589,7 +589,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
   g_signal_connect (G_OBJECT (window), "selection-received",
                                 G_CALLBACK (signal_selection_received), NULL);
   /* en:MDI */
-  mdi = misc_mdi_new ();
+  mdi = orz_mdi_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (mdi), TRUE);
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
   g_signal_connect (G_OBJECT (mdi), "close-window",
@@ -600,60 +600,24 @@ TMAID_COPYRIGHT_NOTICE"\n"
                                 G_CALLBACK (signal_destroy_mdi), NULL);
   /* ja:ポップアップ */
   accel_group = gtk_accel_group_new ();
-  ifactory_popup = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", accel_group);
-  gtk_item_factory_set_translate_func (ifactory_popup, menu_translate,
-                                                                NULL, NULL);
-  gtk_item_factory_create_items (ifactory_popup,
-                        sizeof (popup_items) / sizeof (GtkItemFactoryEntry),
-                                                            popup_items, NULL);
+  misc_create_menu (popup_entries, accel_group);
   /* ja:メニュー */
   accel_group = gtk_accel_group_new ();
-  ifactory_menu = gtk_item_factory_new (GTK_TYPE_MENU_BAR,
-                                                        "<main>", accel_group);
-  gtk_item_factory_set_translate_func (ifactory_menu, menu_translate,
-                                                                NULL, NULL);
-  gtk_item_factory_create_items (ifactory_menu,
-                        sizeof (menu_items) / sizeof (GtkItemFactoryEntry),
-                                                            menu_items, NULL);
-  menu_bar = gtk_item_factory_get_widget (ifactory_menu, "<main>");
+  misc_create_menu (menu_entries, accel_group);
   /* ja:ファイルの履歴 */
-  misc_history_set_menu (MISC_HISTORY (history),
-    gtk_item_factory_get_widget (ifactory_menu, "<main>/File"), MENUFILE - 2);
-  g_signal_connect (MISC_HISTORY (history), "activate",
+  orz_history_set_menu (ORZ_HISTORY (history),
+                        misc_find_menu (menu_entries, "/file/"), MENUFILE - 2);
+  g_signal_connect (ORZ_HISTORY (history), "activate",
                             G_CALLBACK (signal_activate_menu_history), NULL);
   /* ja:ウインドウメニュー */
-  winmenu = misc_winmenu_new ();
-  misc_winmenu_set_mdi (MISC_WINMENU (winmenu), MISC_MDI (mdi));
-  misc_winmenu_set_menu (MISC_WINMENU (winmenu),
-            gtk_item_factory_get_widget (ifactory_menu, "<main>/Window"), 0);
+  winmenu = orz_winmenu_new ();
+  orz_winmenu_set_mdi (ORZ_WINMENU (winmenu), ORZ_MDI (mdi));
+  orz_winmenu_set_menu (ORZ_WINMENU (winmenu),
+                                misc_find_menu (menu_entries, "/window/"), 0);
   /* ja:アクセルグループ */
-  accel = misc_accel_new ();
-  misc_accel_set_window (MISC_ACCEL (accel), GTK_WINDOW (window));
-  misc_accel_add_accel_group (MISC_ACCEL (accel), accel_group);
-  /* ja:ツールバー */
-  toolbar = gtk_toolbar_new ();
-  gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
-                                                GTK_ORIENTATION_HORIZONTAL);
-  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
-  for (i = 0; toolbar_items[i].name != (gpointer)-1; i++)
-    if (toolbar_items[i].name)
-      {
-        GdkBitmap *mask;
-        GdkPixmap *pixmap;
-
-        pixmap = gdk_pixmap_create_from_xpm_d (window->window,
-                                            &mask, NULL, toolbar_items[i].xpm);
-        toolbar_items[i].item = gtk_toolbar_append_item
-                                (GTK_TOOLBAR (toolbar),
-                                NULL, _(toolbar_items[i].name), NULL,
-                                gtk_pixmap_new (pixmap, mask),
-                                GTK_SIGNAL_FUNC (toolbar_items[i].callback),
-                                toolbar_items[i].user_data);
-      }
-    else
-      {
-        gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
-      }
+  accel = orz_accel_new ();
+  orz_accel_set_window (ORZ_ACCEL (accel), GTK_WINDOW (window));
+  orz_accel_add_accel_group (ORZ_ACCEL (accel), accel_group);
   /* ja:テーブル */
   table = gtk_table_new (1, 5, FALSE);
   /* ja:ステータスバー */
@@ -671,11 +635,13 @@ TMAID_COPYRIGHT_NOTICE"\n"
   vbox = gtk_vbox_new (FALSE, 0);
   handle = gtk_handle_box_new ();
   gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
-  gtk_container_add (GTK_CONTAINER (handle), menu_bar);
+  gtk_container_add (GTK_CONTAINER (handle),
+                                        misc_find_menu (menu_entries, "/"));
   gtk_box_pack_start (GTK_BOX (vbox), handle, FALSE, FALSE, 0);
   handle = gtk_handle_box_new ();
   gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
-  gtk_container_add (GTK_CONTAINER (handle), toolbar);
+  gtk_container_add (GTK_CONTAINER (handle),
+                                        misc_create_toolbar (toolbar_entries));
   gtk_box_pack_start (GTK_BOX (vbox), handle, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), mdi, TRUE, TRUE, 0);
   gtk_table_attach (GTK_TABLE (table), status, 0, 4, 0, 1,
@@ -696,10 +662,10 @@ TMAID_COPYRIGHT_NOTICE"\n"
     {
       GObject *comm;
 
-      comm = misc_comm_new (window, "Text maid InterProcess communication");
-      if (!misc_comm_is_first (MISC_COMM (comm)))
+      comm = orz_comm_new (window, "Text maid InterProcess communication");
+      if (!orz_comm_is_first (ORZ_COMM (comm)))
         {
-          misc_comm_send_with_files (MISC_COMM (comm), argc, argv, arg_files);
+          orz_comm_send_with_files (ORZ_COMM (comm), argc, argv, arg_files);
           gtk_exit (0);
         }
       g_signal_connect (G_OBJECT (comm), "recv",
@@ -750,7 +716,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
       gint num;
       GList *glist;
 
-      num = misc_history_get_num (MISC_HISTORY (history));
+      num = orz_history_get_num (ORZ_HISTORY (history));
       profile_set_value (profile, "tmaid", "license",
             (gpointer)&license, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL);
       profile_set_value (profile, "tmaid", "ftnum",
@@ -796,7 +762,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
             }
         }
       /* ja:ファイルの履歴 */
-      glist = misc_history_get_file (MISC_HISTORY (history));
+      glist = orz_history_get_file (ORZ_HISTORY (history));
       for (i = 0; i < g_list_length (glist); i++)
         {
           key = g_strdup_printf ("history%d", i);
@@ -812,7 +778,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
           g_free (key);
         }
       g_list_free (glist);
-      while (i <= MISC_HISTORY_NUM_MAX)
+      while (i <= ORZ_HISTORY_NUM_MAX)
         {
           key = g_strdup_printf ("history%d", i++);
           profile_delete_key (profile, "tmaid", key);
